import { Body, Controller, Get, Post, Put, Query } from '@nestjs/common';
import { ApiBody, ApiOperation, ApiQuery, ApiTags } from '@nestjs/swagger';
import { CarritoService } from './carrito.service';
import { CarritoCreateDto } from './dto/carrito-create.dto';
import { CarritoUpdateDto } from './dto/carrito-update.dto';
import { CarritoCarritosDto } from './dto/carrito-carritos-dto';
import { CarritoDto } from './dto/carrito.dto';

@Controller('carrito')
@ApiTags('carrito')
export class CarritoController {
  constructor(private carritoService: CarritoService) {}

  @Get('carrito')
  @ApiOperation({
    description: 'Endpoint que retorna la información de un carrito.',
  })
  @ApiQuery({
    description: 'Id del carrito.',
    name: 'id_carrito',
    type: 'string',
  })
  carrito(@Query() query: CarritoDto) {
    return this.carritoService.findById(parseInt(query.id_carrito));
  }

  @Get('carritos')
  @ApiOperation({
    description:
      'Endpoint que retorna 25 carritos de un módulo dependiendo de la página en la que se encuentra el usuario y sus filtros.',
  })
  @ApiQuery({
    description: 'Página en la que se encuentra el usuario.',
    name: 'pagina',
    type: 'string',
  })
  @ApiQuery({
    description: 'Id del módulo.',
    name: 'id_modulo',
    type: 'string',
  })
  @ApiQuery({
    description: 'Id del tipo carrito que se queire usar como filtro.',
    name: 'id_tipo_carrito',
    type: 'string',
    required: false,
  })
  @ApiQuery({
    description: 'Booleano en forma de string que se usará como filtro.',
    name: 'activo',
    type: 'string',
    required: false,
  })
  @ApiQuery({
    description: 'Carrito que se esta buscando.',
    name: 'carrito',
    type: 'string',
    required: false,
  })
  carritos(@Query() query: CarritoCarritosDto) {
    return this.carritoService.findByIdModulo(query);
  }

  @Post()
  @ApiOperation({
    description: 'Endpoint que crea un carrito nuevo en un módulo.',
  })
  @ApiBody({
    description: 'Todas las variables son obligatorias.',
    examples: {
      ejemplo: {
        value: { id_tipo_carrito: 1, id_modulo: 1, marca: '', modelo: '' },
      },
    },
  })
  create(@Body() body: CarritoCreateDto) {
    return this.carritoService.create(
      body.id_tipo_carrito,
      body.id_modulo,
      body.marca,
      body.modelo,
    );
  }

  @Put()
  @ApiOperation({
    description: 'Endpoint que actualiza la información de un carrito.',
  })
  @ApiBody({
    description:
      'Todas las variables a excepción de id_carrito son opcionales.',
    examples: {
      ejemplo: {
        value: {
          id_carrito: 1,
          activo: true,
          carrito: 'C01',
          id_modulo: 1,
          id_tipo_carrito: 1,
          marca: 'marca 1',
          modelo: 'modelo 1',
        },
      },
    },
  })
  update(@Body() body: CarritoUpdateDto) {
    return this.carritoService.update(body);
  }
}
