import { Body, Controller, Delete, Post } from '@nestjs/common';
import { ApiBody, ApiOperation } from '@nestjs/swagger';
import { EquipoProgramaService } from './equipo-programa.service';
import { EquipoProgramaCreateDto } from './dto/equipo-programa-create.dto';
import { EquipoProgramaDeleteDto } from './dto/equipo-programa-delete.dto';
@Controller('equipo-programa')
export class EquipoProgramaController {
  constructor(private equipoProgramaService: EquipoProgramaService) {}

  @Post()
  @ApiOperation({
    description:
      'Endpoint que crea una relación entre un equipo y un programa.',
  })
  @ApiBody({
    description: 'Ambas variables son obligatorios.',
    examples: { ejemplo: { value: { id_equipo: 1, id_programa: 1 } } },
  })
  create(@Body() body: EquipoProgramaCreateDto) {
    return this.equipoProgramaService.create(body.id_equipo, body.id_programa);
  }

  @Delete()
  @ApiOperation({
    description:
      'Endpoint que elimina una relación entre un equipo y un programa.',
  })
  @ApiBody({
    description: 'La variable id_equipo_programa es obligatoria.',
    examples: { ejemplo: { value: { id_equipo_programa: 1 } } },
  })
  delete(@Body() body: EquipoProgramaDeleteDto) {
    return this.equipoProgramaService.delete(body.id_equipo_programa);
  }
}
