import { Body, Controller, Get, Put, Query } from '@nestjs/common';
import { ApiBody, ApiOperation, ApiQuery, ApiTags } from '@nestjs/swagger';
import { InstitucionDiaService } from './institucion-dia.service';
import { IdInstitucionDto } from '../dto/id-institucion.dto';
import { InstitucionDiaUpdateDto } from './dto/institucion-dia-update.dto';

@Controller('institucion-dia')
@ApiTags('institucion-dia')
export class InstitucionDiaController {
  constructor(private institucionDiaService: InstitucionDiaService) {}

  @Get('dias')
  @ApiOperation({
    description: 'Endpoint que retorna todos los días de una institución.',
  })
  @ApiQuery({
    description: 'Id de la institución.',
    name: 'id_institucion',
    type: 'string',
  })
  dias(@Query() query: IdInstitucionDto) {
    return this.institucionDiaService.findAllByIdInstitucion(
      parseInt(query.id_institucion),
    );
  }

  @Put()
  @ApiOperation({
    description: 'Endpoint que actualiza la información de un día.',
  })
  @ApiBody({
    description:
      'Todas las variables a excepción de id_institucion_dia son opcionales.',
    examples: {
      ejemplo: {
        value: {
          id_institucion_dia: 217,
          activo: true,
          hora_inicio: '09:00',
          hora_fin: '17:45',
        },
      },
    },
  })
  update(@Body() body: InstitucionDiaUpdateDto) {
    return this.institucionDiaService.update(body);
  }
}
