import { Body, Controller, Get, Post, Put, Query } from '@nestjs/common';
import { ApiBody, ApiOperation, ApiQuery, ApiTags } from '@nestjs/swagger';
import { InstitucionTipoEntradaService } from './institucion-tipo-entrada.service';
import { IdInstitucionDto } from '../dto/id-institucion.dto';
import { InstitucionTipoEntradaCreateDto } from './dto/institucion-tipo-entrada-create.dto';
import { InstitucionTipoEntradaUpdateDto } from './dto/institucion-tipo-entrada-update.dto';

@Controller('institucion-tipo-entrada')
@ApiTags('institucion-tipo-entrada')
export class InstitucionTipoEntradaController {
  constructor(private tipoEntradaService: InstitucionTipoEntradaService) {}

  @Post()
  @ApiOperation({ description: 'Endpoint que crea un tipo de entrada.' })
  @ApiBody({
    description: 'Es obligatorio mandar la variable tipo_entrada.',
    examples: { ejemplo: { value: { tipo_entrada: '' } } },
  })
  create(@Body() body: InstitucionTipoEntradaCreateDto) {
    return this.tipoEntradaService.create(body.tipo_entrada);
  }

  @Get()
  @ApiOperation({
    description: 'Endpoint que retorna todos los tipos de entrada.',
  })
  get() {
    return this.tipoEntradaService.findAll();
  }

  @Get('tipos-entrada')
  @ApiOperation({
    description:
      'Endpoint que retorna todos los tipos de entradas de una institución.',
  })
  @ApiQuery({
    description: 'Id de la institución',
    name: 'id_institucion',
    type: 'string',
  })
  tiposEntrada(@Query() query: IdInstitucionDto) {
    return this.tipoEntradaService.findAllByIdInstitucion(
      parseInt(query.id_institucion),
    );
  }

  @Get('tipos-entrada-mostrar')
  @ApiOperation({
    description:
      'Endpoint que retorna todos los tipos de entrada de una institución que tengan el campo mostrar en true.',
  })
  @ApiQuery({
    description: 'Id de la institución',
    name: 'id_institucion',
    type: 'string',
  })
  tipoEntradaMostrar(@Query() query: IdInstitucionDto) {
    return this.tipoEntradaService.findAllByIdInstitucionMostrar(
      parseInt(query.id_institucion),
    );
  }

  @Put()
  @ApiOperation({
    description:
      'Endpoint que actualiza la información de el tipo de entrada de una institución',
  })
  @ApiBody({
    description: 'Ambas variables son obligatorias.',
    examples: {
      ejemplo: { value: { id_institucion_tipo_entrada: 130, mostrar: true } },
    },
  })
  update(@Body() body: InstitucionTipoEntradaUpdateDto) {
    return this.tipoEntradaService.update(body);
  }
}
