import { Injectable } from '@nestjs/common';
import { InjectRepository } from '@nestjs/typeorm';
import { Repository } from 'typeorm';
import * as moment from 'moment';
import { InstitucionInfraccion } from '../institucion-infraccion/entity/institucion-infraccion.entity';
import { Multa } from './entity/multa.entity';
import { Prestamo } from '../prestamo/entity/prestamo.entity';
import { EquipoService } from '../equipo/equipo.service';
import { InstitucionService } from '../institucion/institucion.service';
import { InstitucionInfraccionService } from '../institucion-infraccion/institucion-infraccion.service';
import { OperadorService } from '../operador/operador.service';
import { PrestamoService } from '../prestamo/prestamo.service';
import { UsuarioService } from '../usuario/usuario.service';

@Injectable()
export class MultaService {
  constructor(
    @InjectRepository(Multa) private repository: Repository<Multa>,
    private equipoService: EquipoService,
    private institucionService: InstitucionService,
    private institucionInfraccionService: InstitucionInfraccionService,
    private operadorService: OperadorService,
    private prestamoService: PrestamoService,
    private usuarioService: UsuarioService,
  ) {}

  async create(
    id_institucion_infraccion: number,
    id_prestamo: number,
    id_operador: number,
    retraso: boolean,
  ) {
    const prestamo = await this.prestamoService.findById(id_prestamo);
    const operador = await this.operadorService.findById(id_operador);
    const institucionInfraccion = id_institucion_infraccion
      ? await this.institucionInfraccionService.findById(
          id_institucion_infraccion,
        )
      : null;
    const data: {
      prestamo: Prestamo;
      institucionInfraccion?: InstitucionInfraccion;
      retraso?: boolean;
    } = { prestamo };

    // const nuevo
    // this.repository.create({
    //   institucionInfraccion,
    //   prestamo,
    //   fecha_inicio: new Date(),
    // });

    if (retraso) data.retraso = retraso;
    if (institucionInfraccion) data.institucionInfraccion;
  }

  findAllByIdInstitucion(id_institucion: number, pagina: number) {
    return this.institucionService
      .findById(id_institucion)
      .then((institucion) =>
        this.repository.findAndCount({
          where: {},
          skip: (pagina - 1) * 25,
          take: 25,
        }),
      );
  }

  findAllByIdEquipo(id_equipo: number, pagina: number) {
    return this.equipoService.findById(id_equipo).then((equipo) =>
      this.repository.findAndCount({
        where: { prestamo: { equipo } },
        skip: (pagina - 1) * 25,
        take: 25,
      }),
    );
  }

  findAllByIdUsuario(id_usuario: number, pagina: number) {
    return this.usuarioService.findById(id_usuario).then((usuario) =>
      this.repository.findAndCount({
        where: { prestamo: { usuario } },
        skip: (pagina - 1) * 25,
        take: 25,
      }),
    );
  }
}
